# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tinkoff/cloud/stt/v1/stt.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from astersay.backends.google.proto.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from astersay.backends.tinkoff.proto import longrunning_pb2 as tinkoff_dot_cloud_dot_longrunning_dot_v1_dot_longrunning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tinkoff/cloud/stt/v1/stt.proto',
  package='tinkoff.cloud.stt.v1',
  syntax='proto3',
  serialized_options=b'ZQgithub.com/TinkoffCreditSystems/voicekit-examples/golang/pkg/tinkoff/cloud/stt/v1\242\002\005TVKSR',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1etinkoff/cloud/stt/v1/stt.proto\x12\x14tinkoff.cloud.stt.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/api/annotations.proto\x1a.tinkoff/cloud/longrunning/v1/longrunning.proto\"D\n\x10RecognitionAudio\x12\x11\n\x07\x63ontent\x18\x01 \x01(\x0cH\x00\x12\r\n\x03uri\x18\x02 \x01(\tH\x00\x42\x0e\n\x0c\x61udio_source\"2\n\x13SpeechContextPhrase\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x02\"W\n\rSpeechContext\x12:\n\x07phrases\x18\x03 \x03(\x0b\x32).tinkoff.cloud.stt.v1.SpeechContextPhraseJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"\x88\x01\n\x08WordInfo\x12-\n\nstart_time\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0c\n\x04word\x18\x03 \x01(\t\x12\x12\n\nconfidence\x18\x04 \x01(\x02\"\xb4\x01\n\x1cVoiceActivityDetectionConfig\x12\x1b\n\x13min_speech_duration\x18\x01 \x01(\x02\x12\x1b\n\x13max_speech_duration\x18\x02 \x01(\x02\x12\"\n\x1asilence_duration_threshold\x18\x03 \x01(\x02\x12\x1e\n\x16silence_prob_threshold\x18\x04 \x01(\x02\x12\x16\n\x0e\x61ggressiveness\x18\x05 \x01(\x02\"\xdb\x04\n\x11RecognitionConfig\x12\x35\n\x08\x65ncoding\x18\x01 \x01(\x0e\x32#.tinkoff.cloud.stt.v1.AudioEncoding\x12\x19\n\x11sample_rate_hertz\x18\x02 \x01(\r\x12\x15\n\rlanguage_code\x18\x03 \x01(\t\x12\x18\n\x10max_alternatives\x18\x04 \x01(\r\x12\x18\n\x10profanity_filter\x18\x05 \x01(\x08\x12<\n\x0fspeech_contexts\x18\x06 \x03(\x0b\x32#.tinkoff.cloud.stt.v1.SpeechContext\x12$\n\x1c\x65nable_automatic_punctuation\x18\x08 \x01(\x08\x12\r\n\x05model\x18\n \x01(\t\x12\x14\n\x0cnum_channels\x18\x0c \x01(\r\x12\x1c\n\x12\x64o_not_perform_vad\x18\r \x01(\x08H\x00\x12H\n\nvad_config\x18\x0e \x01(\x0b\x32\x32.tinkoff.cloud.stt.v1.VoiceActivityDetectionConfigH\x00\x12\x1e\n\x16\x65nable_denormalization\x18\x10 \x01(\x08\x12!\n\x19\x65nable_sentiment_analysis\x18\x11 \x01(\x08\x12$\n\x1c\x65nable_gender_identification\x18\x12 \x01(\x08\x42\x05\n\x03vadJ\x04\x08\x07\x10\x08J\x04\x08\t\x10\nJ\x04\x08\x0b\x10\x0cJ\x04\x08\x0f\x10\x10R\x18\x65nable_word_time_offsetsR\x08metadataR\x0cuse_enhanced\"\x82\x01\n\x10RecognizeRequest\x12\x37\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\'.tinkoff.cloud.stt.v1.RecognitionConfig\x12\x35\n\x05\x61udio\x18\x02 \x01(\x0b\x32&.tinkoff.cloud.stt.v1.RecognitionAudio\"u\n\x1cSpeechRecognitionAlternative\x12\x12\n\ntranscript\x18\x01 \x01(\t\x12\x12\n\nconfidence\x18\x02 \x01(\x02\x12-\n\x05words\x18\x03 \x03(\x0b\x32\x1e.tinkoff.cloud.stt.v1.WordInfo\"^\n\x1dSpeechSentimentAnalysisResult\x12\x1b\n\x13negative_prob_audio\x18\x01 \x01(\x02\x12 \n\x18negative_prob_audio_text\x18\x02 \x01(\x02\"L\n SpeechGenderIdentificationResult\x12\x12\n\nmale_proba\x18\x01 \x01(\x02\x12\x14\n\x0c\x66\x65male_proba\x18\x02 \x01(\x02\"\x86\x03\n\x17SpeechRecognitionResult\x12H\n\x0c\x61lternatives\x18\x01 \x03(\x0b\x32\x32.tinkoff.cloud.stt.v1.SpeechRecognitionAlternative\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\x05\x12-\n\nstart_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\x12V\n\x19sentiment_analysis_result\x18\x05 \x01(\x0b\x32\x33.tinkoff.cloud.stt.v1.SpeechSentimentAnalysisResult\x12\\\n\x1cgender_identification_result\x18\x06 \x01(\x0b\x32\x36.tinkoff.cloud.stt.v1.SpeechGenderIdentificationResult\"S\n\x11RecognizeResponse\x12>\n\x07results\x18\x01 \x03(\x0b\x32-.tinkoff.cloud.stt.v1.SpeechRecognitionResult\"H\n\x14InterimResultsConfig\x12\x1e\n\x16\x65nable_interim_results\x18\x01 \x01(\x08\x12\x10\n\x08interval\x18\x02 \x01(\x02\"\x9c\x01\n\x1bLongRunningRecognizeRequest\x12\x37\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\'.tinkoff.cloud.stt.v1.RecognitionConfig\x12\x35\n\x05\x61udio\x18\x02 \x01(\x0b\x32&.tinkoff.cloud.stt.v1.RecognitionAudio\x12\r\n\x05group\x18\x03 \x01(\t\"\xbb\x01\n\x1aStreamingRecognitionConfig\x12\x37\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\'.tinkoff.cloud.stt.v1.RecognitionConfig\x12\x18\n\x10single_utterance\x18\x02 \x01(\x08\x12J\n\x16interim_results_config\x18\x03 \x01(\x0b\x32*.tinkoff.cloud.stt.v1.InterimResultsConfig\"\x97\x01\n\x19StreamingRecognizeRequest\x12L\n\x10streaming_config\x18\x01 \x01(\x0b\x32\x30.tinkoff.cloud.stt.v1.StreamingRecognitionConfigH\x00\x12\x17\n\raudio_content\x18\x02 \x01(\x0cH\x00\x42\x13\n\x11streaming_request\"\x8c\x01\n\x1aStreamingRecognitionResult\x12I\n\x12recognition_result\x18\x01 \x01(\x0b\x32-.tinkoff.cloud.stt.v1.SpeechRecognitionResult\x12\x10\n\x08is_final\x18\x02 \x01(\x08\x12\x11\n\tstability\x18\x03 \x01(\x02\"k\n\x1aStreamingRecognizeResponse\x12\x41\n\x07results\x18\x02 \x03(\x0b\x32\x30.tinkoff.cloud.stt.v1.StreamingRecognitionResultJ\x04\x08\x01\x10\x02J\x04\x08\x03\x10\x04*\xe0\x01\n\rAudioEncoding\x12\x18\n\x14\x45NCODING_UNSPECIFIED\x10\x00\x12\x0c\n\x08LINEAR16\x10\x01\x12\t\n\x05MULAW\x10\x03\x12\x08\n\x04\x41LAW\x10\x08\x12\x0c\n\x08RAW_OPUS\x10\x0b\x12\x0e\n\nMPEG_AUDIO\x10\x0c\"\x04\x08\x02\x10\x02\"\x04\x08\x04\x10\x04\"\x04\x08\x05\x10\x05\"\x04\x08\x06\x10\x06\"\x04\x08\x07\x10\x07\"\x04\x08\t\x10\t\"\x04\x08\n\x10\n*\x04\x46LAC*\x03\x41MR*\x06\x41MR_WB*\x08OGG_OPUS*\x16SPEEX_WITH_HEADER_BYTE*\tLINEAR32F*\nOGG_VORBIS2\xa5\x03\n\x0cSpeechToText\x12z\n\tRecognize\x12&.tinkoff.cloud.stt.v1.RecognizeRequest\x1a\'.tinkoff.cloud.stt.v1.RecognizeResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/stt:recognize:\x01*\x12{\n\x12StreamingRecognize\x12/.tinkoff.cloud.stt.v1.StreamingRecognizeRequest\x1a\x30.tinkoff.cloud.stt.v1.StreamingRecognizeResponse(\x01\x30\x01\x12\x9b\x01\n\x14LongRunningRecognize\x12\x31.tinkoff.cloud.stt.v1.LongRunningRecognizeRequest\x1a\'.tinkoff.cloud.longrunning.v1.Operation\"\'\x82\xd3\xe4\x93\x02!\"\x1c/v1/stt:longrunningrecognize:\x01*B[ZQgithub.com/TinkoffCreditSystems/voicekit-examples/golang/pkg/tinkoff/cloud/stt/v1\xa2\x02\x05TVKSRb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,tinkoff_dot_cloud_dot_longrunning_dot_v1_dot_longrunning__pb2.DESCRIPTOR,])

_AUDIOENCODING = _descriptor.EnumDescriptor(
  name='AudioEncoding',
  full_name='tinkoff.cloud.stt.v1.AudioEncoding',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ENCODING_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LINEAR16', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MULAW', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALAW', index=3, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RAW_OPUS', index=4, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MPEG_AUDIO', index=5, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3039,
  serialized_end=3263,
)
_sym_db.RegisterEnumDescriptor(_AUDIOENCODING)

AudioEncoding = enum_type_wrapper.EnumTypeWrapper(_AUDIOENCODING)
ENCODING_UNSPECIFIED = 0
LINEAR16 = 1
MULAW = 3
ALAW = 8
RAW_OPUS = 11
MPEG_AUDIO = 12



_RECOGNITIONAUDIO = _descriptor.Descriptor(
  name='RecognitionAudio',
  full_name='tinkoff.cloud.stt.v1.RecognitionAudio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='content', full_name='tinkoff.cloud.stt.v1.RecognitionAudio.content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='tinkoff.cloud.stt.v1.RecognitionAudio.uri', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='audio_source', full_name='tinkoff.cloud.stt.v1.RecognitionAudio.audio_source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=166,
  serialized_end=234,
)


_SPEECHCONTEXTPHRASE = _descriptor.Descriptor(
  name='SpeechContextPhrase',
  full_name='tinkoff.cloud.stt.v1.SpeechContextPhrase',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='tinkoff.cloud.stt.v1.SpeechContextPhrase.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='score', full_name='tinkoff.cloud.stt.v1.SpeechContextPhrase.score', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=236,
  serialized_end=286,
)


_SPEECHCONTEXT = _descriptor.Descriptor(
  name='SpeechContext',
  full_name='tinkoff.cloud.stt.v1.SpeechContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='phrases', full_name='tinkoff.cloud.stt.v1.SpeechContext.phrases', index=0,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=288,
  serialized_end=375,
)


_WORDINFO = _descriptor.Descriptor(
  name='WordInfo',
  full_name='tinkoff.cloud.stt.v1.WordInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_time', full_name='tinkoff.cloud.stt.v1.WordInfo.start_time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='tinkoff.cloud.stt.v1.WordInfo.end_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='word', full_name='tinkoff.cloud.stt.v1.WordInfo.word', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='tinkoff.cloud.stt.v1.WordInfo.confidence', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=378,
  serialized_end=514,
)


_VOICEACTIVITYDETECTIONCONFIG = _descriptor.Descriptor(
  name='VoiceActivityDetectionConfig',
  full_name='tinkoff.cloud.stt.v1.VoiceActivityDetectionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_speech_duration', full_name='tinkoff.cloud.stt.v1.VoiceActivityDetectionConfig.min_speech_duration', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_speech_duration', full_name='tinkoff.cloud.stt.v1.VoiceActivityDetectionConfig.max_speech_duration', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='silence_duration_threshold', full_name='tinkoff.cloud.stt.v1.VoiceActivityDetectionConfig.silence_duration_threshold', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='silence_prob_threshold', full_name='tinkoff.cloud.stt.v1.VoiceActivityDetectionConfig.silence_prob_threshold', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aggressiveness', full_name='tinkoff.cloud.stt.v1.VoiceActivityDetectionConfig.aggressiveness', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=517,
  serialized_end=697,
)


_RECOGNITIONCONFIG = _descriptor.Descriptor(
  name='RecognitionConfig',
  full_name='tinkoff.cloud.stt.v1.RecognitionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='encoding', full_name='tinkoff.cloud.stt.v1.RecognitionConfig.encoding', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sample_rate_hertz', full_name='tinkoff.cloud.stt.v1.RecognitionConfig.sample_rate_hertz', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language_code', full_name='tinkoff.cloud.stt.v1.RecognitionConfig.language_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_alternatives', full_name='tinkoff.cloud.stt.v1.RecognitionConfig.max_alternatives', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='profanity_filter', full_name='tinkoff.cloud.stt.v1.RecognitionConfig.profanity_filter', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speech_contexts', full_name='tinkoff.cloud.stt.v1.RecognitionConfig.speech_contexts', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_automatic_punctuation', full_name='tinkoff.cloud.stt.v1.RecognitionConfig.enable_automatic_punctuation', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model', full_name='tinkoff.cloud.stt.v1.RecognitionConfig.model', index=7,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_channels', full_name='tinkoff.cloud.stt.v1.RecognitionConfig.num_channels', index=8,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='do_not_perform_vad', full_name='tinkoff.cloud.stt.v1.RecognitionConfig.do_not_perform_vad', index=9,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vad_config', full_name='tinkoff.cloud.stt.v1.RecognitionConfig.vad_config', index=10,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_denormalization', full_name='tinkoff.cloud.stt.v1.RecognitionConfig.enable_denormalization', index=11,
      number=16, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_sentiment_analysis', full_name='tinkoff.cloud.stt.v1.RecognitionConfig.enable_sentiment_analysis', index=12,
      number=17, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_gender_identification', full_name='tinkoff.cloud.stt.v1.RecognitionConfig.enable_gender_identification', index=13,
      number=18, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='vad', full_name='tinkoff.cloud.stt.v1.RecognitionConfig.vad',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=700,
  serialized_end=1303,
)


_RECOGNIZEREQUEST = _descriptor.Descriptor(
  name='RecognizeRequest',
  full_name='tinkoff.cloud.stt.v1.RecognizeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='tinkoff.cloud.stt.v1.RecognizeRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audio', full_name='tinkoff.cloud.stt.v1.RecognizeRequest.audio', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1306,
  serialized_end=1436,
)


_SPEECHRECOGNITIONALTERNATIVE = _descriptor.Descriptor(
  name='SpeechRecognitionAlternative',
  full_name='tinkoff.cloud.stt.v1.SpeechRecognitionAlternative',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transcript', full_name='tinkoff.cloud.stt.v1.SpeechRecognitionAlternative.transcript', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='tinkoff.cloud.stt.v1.SpeechRecognitionAlternative.confidence', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='words', full_name='tinkoff.cloud.stt.v1.SpeechRecognitionAlternative.words', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1438,
  serialized_end=1555,
)


_SPEECHSENTIMENTANALYSISRESULT = _descriptor.Descriptor(
  name='SpeechSentimentAnalysisResult',
  full_name='tinkoff.cloud.stt.v1.SpeechSentimentAnalysisResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='negative_prob_audio', full_name='tinkoff.cloud.stt.v1.SpeechSentimentAnalysisResult.negative_prob_audio', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='negative_prob_audio_text', full_name='tinkoff.cloud.stt.v1.SpeechSentimentAnalysisResult.negative_prob_audio_text', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1557,
  serialized_end=1651,
)


_SPEECHGENDERIDENTIFICATIONRESULT = _descriptor.Descriptor(
  name='SpeechGenderIdentificationResult',
  full_name='tinkoff.cloud.stt.v1.SpeechGenderIdentificationResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='male_proba', full_name='tinkoff.cloud.stt.v1.SpeechGenderIdentificationResult.male_proba', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='female_proba', full_name='tinkoff.cloud.stt.v1.SpeechGenderIdentificationResult.female_proba', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1653,
  serialized_end=1729,
)


_SPEECHRECOGNITIONRESULT = _descriptor.Descriptor(
  name='SpeechRecognitionResult',
  full_name='tinkoff.cloud.stt.v1.SpeechRecognitionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alternatives', full_name='tinkoff.cloud.stt.v1.SpeechRecognitionResult.alternatives', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel', full_name='tinkoff.cloud.stt.v1.SpeechRecognitionResult.channel', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='tinkoff.cloud.stt.v1.SpeechRecognitionResult.start_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='tinkoff.cloud.stt.v1.SpeechRecognitionResult.end_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sentiment_analysis_result', full_name='tinkoff.cloud.stt.v1.SpeechRecognitionResult.sentiment_analysis_result', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gender_identification_result', full_name='tinkoff.cloud.stt.v1.SpeechRecognitionResult.gender_identification_result', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1732,
  serialized_end=2122,
)


_RECOGNIZERESPONSE = _descriptor.Descriptor(
  name='RecognizeResponse',
  full_name='tinkoff.cloud.stt.v1.RecognizeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='tinkoff.cloud.stt.v1.RecognizeResponse.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2124,
  serialized_end=2207,
)


_INTERIMRESULTSCONFIG = _descriptor.Descriptor(
  name='InterimResultsConfig',
  full_name='tinkoff.cloud.stt.v1.InterimResultsConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable_interim_results', full_name='tinkoff.cloud.stt.v1.InterimResultsConfig.enable_interim_results', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='tinkoff.cloud.stt.v1.InterimResultsConfig.interval', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2209,
  serialized_end=2281,
)


_LONGRUNNINGRECOGNIZEREQUEST = _descriptor.Descriptor(
  name='LongRunningRecognizeRequest',
  full_name='tinkoff.cloud.stt.v1.LongRunningRecognizeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='tinkoff.cloud.stt.v1.LongRunningRecognizeRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audio', full_name='tinkoff.cloud.stt.v1.LongRunningRecognizeRequest.audio', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='group', full_name='tinkoff.cloud.stt.v1.LongRunningRecognizeRequest.group', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2284,
  serialized_end=2440,
)


_STREAMINGRECOGNITIONCONFIG = _descriptor.Descriptor(
  name='StreamingRecognitionConfig',
  full_name='tinkoff.cloud.stt.v1.StreamingRecognitionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='tinkoff.cloud.stt.v1.StreamingRecognitionConfig.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='single_utterance', full_name='tinkoff.cloud.stt.v1.StreamingRecognitionConfig.single_utterance', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interim_results_config', full_name='tinkoff.cloud.stt.v1.StreamingRecognitionConfig.interim_results_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2443,
  serialized_end=2630,
)


_STREAMINGRECOGNIZEREQUEST = _descriptor.Descriptor(
  name='StreamingRecognizeRequest',
  full_name='tinkoff.cloud.stt.v1.StreamingRecognizeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='streaming_config', full_name='tinkoff.cloud.stt.v1.StreamingRecognizeRequest.streaming_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audio_content', full_name='tinkoff.cloud.stt.v1.StreamingRecognizeRequest.audio_content', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='streaming_request', full_name='tinkoff.cloud.stt.v1.StreamingRecognizeRequest.streaming_request',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2633,
  serialized_end=2784,
)


_STREAMINGRECOGNITIONRESULT = _descriptor.Descriptor(
  name='StreamingRecognitionResult',
  full_name='tinkoff.cloud.stt.v1.StreamingRecognitionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='recognition_result', full_name='tinkoff.cloud.stt.v1.StreamingRecognitionResult.recognition_result', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_final', full_name='tinkoff.cloud.stt.v1.StreamingRecognitionResult.is_final', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stability', full_name='tinkoff.cloud.stt.v1.StreamingRecognitionResult.stability', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2787,
  serialized_end=2927,
)


_STREAMINGRECOGNIZERESPONSE = _descriptor.Descriptor(
  name='StreamingRecognizeResponse',
  full_name='tinkoff.cloud.stt.v1.StreamingRecognizeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='tinkoff.cloud.stt.v1.StreamingRecognizeResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2929,
  serialized_end=3036,
)

_RECOGNITIONAUDIO.oneofs_by_name['audio_source'].fields.append(
  _RECOGNITIONAUDIO.fields_by_name['content'])
_RECOGNITIONAUDIO.fields_by_name['content'].containing_oneof = _RECOGNITIONAUDIO.oneofs_by_name['audio_source']
_RECOGNITIONAUDIO.oneofs_by_name['audio_source'].fields.append(
  _RECOGNITIONAUDIO.fields_by_name['uri'])
_RECOGNITIONAUDIO.fields_by_name['uri'].containing_oneof = _RECOGNITIONAUDIO.oneofs_by_name['audio_source']
_SPEECHCONTEXT.fields_by_name['phrases'].message_type = _SPEECHCONTEXTPHRASE
_WORDINFO.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_WORDINFO.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_RECOGNITIONCONFIG.fields_by_name['encoding'].enum_type = _AUDIOENCODING
_RECOGNITIONCONFIG.fields_by_name['speech_contexts'].message_type = _SPEECHCONTEXT
_RECOGNITIONCONFIG.fields_by_name['vad_config'].message_type = _VOICEACTIVITYDETECTIONCONFIG
_RECOGNITIONCONFIG.oneofs_by_name['vad'].fields.append(
  _RECOGNITIONCONFIG.fields_by_name['do_not_perform_vad'])
_RECOGNITIONCONFIG.fields_by_name['do_not_perform_vad'].containing_oneof = _RECOGNITIONCONFIG.oneofs_by_name['vad']
_RECOGNITIONCONFIG.oneofs_by_name['vad'].fields.append(
  _RECOGNITIONCONFIG.fields_by_name['vad_config'])
_RECOGNITIONCONFIG.fields_by_name['vad_config'].containing_oneof = _RECOGNITIONCONFIG.oneofs_by_name['vad']
_RECOGNIZEREQUEST.fields_by_name['config'].message_type = _RECOGNITIONCONFIG
_RECOGNIZEREQUEST.fields_by_name['audio'].message_type = _RECOGNITIONAUDIO
_SPEECHRECOGNITIONALTERNATIVE.fields_by_name['words'].message_type = _WORDINFO
_SPEECHRECOGNITIONRESULT.fields_by_name['alternatives'].message_type = _SPEECHRECOGNITIONALTERNATIVE
_SPEECHRECOGNITIONRESULT.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_SPEECHRECOGNITIONRESULT.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_SPEECHRECOGNITIONRESULT.fields_by_name['sentiment_analysis_result'].message_type = _SPEECHSENTIMENTANALYSISRESULT
_SPEECHRECOGNITIONRESULT.fields_by_name['gender_identification_result'].message_type = _SPEECHGENDERIDENTIFICATIONRESULT
_RECOGNIZERESPONSE.fields_by_name['results'].message_type = _SPEECHRECOGNITIONRESULT
_LONGRUNNINGRECOGNIZEREQUEST.fields_by_name['config'].message_type = _RECOGNITIONCONFIG
_LONGRUNNINGRECOGNIZEREQUEST.fields_by_name['audio'].message_type = _RECOGNITIONAUDIO
_STREAMINGRECOGNITIONCONFIG.fields_by_name['config'].message_type = _RECOGNITIONCONFIG
_STREAMINGRECOGNITIONCONFIG.fields_by_name['interim_results_config'].message_type = _INTERIMRESULTSCONFIG
_STREAMINGRECOGNIZEREQUEST.fields_by_name['streaming_config'].message_type = _STREAMINGRECOGNITIONCONFIG
_STREAMINGRECOGNIZEREQUEST.oneofs_by_name['streaming_request'].fields.append(
  _STREAMINGRECOGNIZEREQUEST.fields_by_name['streaming_config'])
_STREAMINGRECOGNIZEREQUEST.fields_by_name['streaming_config'].containing_oneof = _STREAMINGRECOGNIZEREQUEST.oneofs_by_name['streaming_request']
_STREAMINGRECOGNIZEREQUEST.oneofs_by_name['streaming_request'].fields.append(
  _STREAMINGRECOGNIZEREQUEST.fields_by_name['audio_content'])
_STREAMINGRECOGNIZEREQUEST.fields_by_name['audio_content'].containing_oneof = _STREAMINGRECOGNIZEREQUEST.oneofs_by_name['streaming_request']
_STREAMINGRECOGNITIONRESULT.fields_by_name['recognition_result'].message_type = _SPEECHRECOGNITIONRESULT
_STREAMINGRECOGNIZERESPONSE.fields_by_name['results'].message_type = _STREAMINGRECOGNITIONRESULT
DESCRIPTOR.message_types_by_name['RecognitionAudio'] = _RECOGNITIONAUDIO
DESCRIPTOR.message_types_by_name['SpeechContextPhrase'] = _SPEECHCONTEXTPHRASE
DESCRIPTOR.message_types_by_name['SpeechContext'] = _SPEECHCONTEXT
DESCRIPTOR.message_types_by_name['WordInfo'] = _WORDINFO
DESCRIPTOR.message_types_by_name['VoiceActivityDetectionConfig'] = _VOICEACTIVITYDETECTIONCONFIG
DESCRIPTOR.message_types_by_name['RecognitionConfig'] = _RECOGNITIONCONFIG
DESCRIPTOR.message_types_by_name['RecognizeRequest'] = _RECOGNIZEREQUEST
DESCRIPTOR.message_types_by_name['SpeechRecognitionAlternative'] = _SPEECHRECOGNITIONALTERNATIVE
DESCRIPTOR.message_types_by_name['SpeechSentimentAnalysisResult'] = _SPEECHSENTIMENTANALYSISRESULT
DESCRIPTOR.message_types_by_name['SpeechGenderIdentificationResult'] = _SPEECHGENDERIDENTIFICATIONRESULT
DESCRIPTOR.message_types_by_name['SpeechRecognitionResult'] = _SPEECHRECOGNITIONRESULT
DESCRIPTOR.message_types_by_name['RecognizeResponse'] = _RECOGNIZERESPONSE
DESCRIPTOR.message_types_by_name['InterimResultsConfig'] = _INTERIMRESULTSCONFIG
DESCRIPTOR.message_types_by_name['LongRunningRecognizeRequest'] = _LONGRUNNINGRECOGNIZEREQUEST
DESCRIPTOR.message_types_by_name['StreamingRecognitionConfig'] = _STREAMINGRECOGNITIONCONFIG
DESCRIPTOR.message_types_by_name['StreamingRecognizeRequest'] = _STREAMINGRECOGNIZEREQUEST
DESCRIPTOR.message_types_by_name['StreamingRecognitionResult'] = _STREAMINGRECOGNITIONRESULT
DESCRIPTOR.message_types_by_name['StreamingRecognizeResponse'] = _STREAMINGRECOGNIZERESPONSE
DESCRIPTOR.enum_types_by_name['AudioEncoding'] = _AUDIOENCODING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RecognitionAudio = _reflection.GeneratedProtocolMessageType('RecognitionAudio', (_message.Message,), {
  'DESCRIPTOR' : _RECOGNITIONAUDIO,
  '__module__' : 'tinkoff.cloud.stt.v1.stt_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.stt.v1.RecognitionAudio)
  })
_sym_db.RegisterMessage(RecognitionAudio)

SpeechContextPhrase = _reflection.GeneratedProtocolMessageType('SpeechContextPhrase', (_message.Message,), {
  'DESCRIPTOR' : _SPEECHCONTEXTPHRASE,
  '__module__' : 'tinkoff.cloud.stt.v1.stt_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.stt.v1.SpeechContextPhrase)
  })
_sym_db.RegisterMessage(SpeechContextPhrase)

SpeechContext = _reflection.GeneratedProtocolMessageType('SpeechContext', (_message.Message,), {
  'DESCRIPTOR' : _SPEECHCONTEXT,
  '__module__' : 'tinkoff.cloud.stt.v1.stt_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.stt.v1.SpeechContext)
  })
_sym_db.RegisterMessage(SpeechContext)

WordInfo = _reflection.GeneratedProtocolMessageType('WordInfo', (_message.Message,), {
  'DESCRIPTOR' : _WORDINFO,
  '__module__' : 'tinkoff.cloud.stt.v1.stt_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.stt.v1.WordInfo)
  })
_sym_db.RegisterMessage(WordInfo)

VoiceActivityDetectionConfig = _reflection.GeneratedProtocolMessageType('VoiceActivityDetectionConfig', (_message.Message,), {
  'DESCRIPTOR' : _VOICEACTIVITYDETECTIONCONFIG,
  '__module__' : 'tinkoff.cloud.stt.v1.stt_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.stt.v1.VoiceActivityDetectionConfig)
  })
_sym_db.RegisterMessage(VoiceActivityDetectionConfig)

RecognitionConfig = _reflection.GeneratedProtocolMessageType('RecognitionConfig', (_message.Message,), {
  'DESCRIPTOR' : _RECOGNITIONCONFIG,
  '__module__' : 'tinkoff.cloud.stt.v1.stt_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.stt.v1.RecognitionConfig)
  })
_sym_db.RegisterMessage(RecognitionConfig)

RecognizeRequest = _reflection.GeneratedProtocolMessageType('RecognizeRequest', (_message.Message,), {
  'DESCRIPTOR' : _RECOGNIZEREQUEST,
  '__module__' : 'tinkoff.cloud.stt.v1.stt_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.stt.v1.RecognizeRequest)
  })
_sym_db.RegisterMessage(RecognizeRequest)

SpeechRecognitionAlternative = _reflection.GeneratedProtocolMessageType('SpeechRecognitionAlternative', (_message.Message,), {
  'DESCRIPTOR' : _SPEECHRECOGNITIONALTERNATIVE,
  '__module__' : 'tinkoff.cloud.stt.v1.stt_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.stt.v1.SpeechRecognitionAlternative)
  })
_sym_db.RegisterMessage(SpeechRecognitionAlternative)

SpeechSentimentAnalysisResult = _reflection.GeneratedProtocolMessageType('SpeechSentimentAnalysisResult', (_message.Message,), {
  'DESCRIPTOR' : _SPEECHSENTIMENTANALYSISRESULT,
  '__module__' : 'tinkoff.cloud.stt.v1.stt_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.stt.v1.SpeechSentimentAnalysisResult)
  })
_sym_db.RegisterMessage(SpeechSentimentAnalysisResult)

SpeechGenderIdentificationResult = _reflection.GeneratedProtocolMessageType('SpeechGenderIdentificationResult', (_message.Message,), {
  'DESCRIPTOR' : _SPEECHGENDERIDENTIFICATIONRESULT,
  '__module__' : 'tinkoff.cloud.stt.v1.stt_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.stt.v1.SpeechGenderIdentificationResult)
  })
_sym_db.RegisterMessage(SpeechGenderIdentificationResult)

SpeechRecognitionResult = _reflection.GeneratedProtocolMessageType('SpeechRecognitionResult', (_message.Message,), {
  'DESCRIPTOR' : _SPEECHRECOGNITIONRESULT,
  '__module__' : 'tinkoff.cloud.stt.v1.stt_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.stt.v1.SpeechRecognitionResult)
  })
_sym_db.RegisterMessage(SpeechRecognitionResult)

RecognizeResponse = _reflection.GeneratedProtocolMessageType('RecognizeResponse', (_message.Message,), {
  'DESCRIPTOR' : _RECOGNIZERESPONSE,
  '__module__' : 'tinkoff.cloud.stt.v1.stt_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.stt.v1.RecognizeResponse)
  })
_sym_db.RegisterMessage(RecognizeResponse)

InterimResultsConfig = _reflection.GeneratedProtocolMessageType('InterimResultsConfig', (_message.Message,), {
  'DESCRIPTOR' : _INTERIMRESULTSCONFIG,
  '__module__' : 'tinkoff.cloud.stt.v1.stt_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.stt.v1.InterimResultsConfig)
  })
_sym_db.RegisterMessage(InterimResultsConfig)

LongRunningRecognizeRequest = _reflection.GeneratedProtocolMessageType('LongRunningRecognizeRequest', (_message.Message,), {
  'DESCRIPTOR' : _LONGRUNNINGRECOGNIZEREQUEST,
  '__module__' : 'tinkoff.cloud.stt.v1.stt_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.stt.v1.LongRunningRecognizeRequest)
  })
_sym_db.RegisterMessage(LongRunningRecognizeRequest)

StreamingRecognitionConfig = _reflection.GeneratedProtocolMessageType('StreamingRecognitionConfig', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGRECOGNITIONCONFIG,
  '__module__' : 'tinkoff.cloud.stt.v1.stt_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.stt.v1.StreamingRecognitionConfig)
  })
_sym_db.RegisterMessage(StreamingRecognitionConfig)

StreamingRecognizeRequest = _reflection.GeneratedProtocolMessageType('StreamingRecognizeRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGRECOGNIZEREQUEST,
  '__module__' : 'tinkoff.cloud.stt.v1.stt_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.stt.v1.StreamingRecognizeRequest)
  })
_sym_db.RegisterMessage(StreamingRecognizeRequest)

StreamingRecognitionResult = _reflection.GeneratedProtocolMessageType('StreamingRecognitionResult', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGRECOGNITIONRESULT,
  '__module__' : 'tinkoff.cloud.stt.v1.stt_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.stt.v1.StreamingRecognitionResult)
  })
_sym_db.RegisterMessage(StreamingRecognitionResult)

StreamingRecognizeResponse = _reflection.GeneratedProtocolMessageType('StreamingRecognizeResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGRECOGNIZERESPONSE,
  '__module__' : 'tinkoff.cloud.stt.v1.stt_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.stt.v1.StreamingRecognizeResponse)
  })
_sym_db.RegisterMessage(StreamingRecognizeResponse)


DESCRIPTOR._options = None

_SPEECHTOTEXT = _descriptor.ServiceDescriptor(
  name='SpeechToText',
  full_name='tinkoff.cloud.stt.v1.SpeechToText',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3266,
  serialized_end=3687,
  methods=[
  _descriptor.MethodDescriptor(
    name='Recognize',
    full_name='tinkoff.cloud.stt.v1.SpeechToText.Recognize',
    index=0,
    containing_service=None,
    input_type=_RECOGNIZEREQUEST,
    output_type=_RECOGNIZERESPONSE,
    serialized_options=b'\202\323\344\223\002\026\"\021/v1/stt:recognize:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamingRecognize',
    full_name='tinkoff.cloud.stt.v1.SpeechToText.StreamingRecognize',
    index=1,
    containing_service=None,
    input_type=_STREAMINGRECOGNIZEREQUEST,
    output_type=_STREAMINGRECOGNIZERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LongRunningRecognize',
    full_name='tinkoff.cloud.stt.v1.SpeechToText.LongRunningRecognize',
    index=2,
    containing_service=None,
    input_type=_LONGRUNNINGRECOGNIZEREQUEST,
    output_type=tinkoff_dot_cloud_dot_longrunning_dot_v1_dot_longrunning__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002!\"\034/v1/stt:longrunningrecognize:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SPEECHTOTEXT)

DESCRIPTOR.services_by_name['SpeechToText'] = _SPEECHTOTEXT

# @@protoc_insertion_point(module_scope)



#
#  Copyright (c) 2021. Egor Demushin.
#  All rights reserved.
#  This file is distributed under the same license as the current project.
#

from .auth import TokenHeaderAuth, TokenAuth, LoginPassAuth, HttpBasicAuth  # NOQA
from .parsers import JsonParser  # NOQA
from .client import BaseHttpClient  # NOQA



#
# Copyright (c) 2020, Grigoriy Kramarenko
# All rights reserved.
# This file is distributed under the same license as the current project.
#
from gettext import gettext as _
from logging import getLogger

from astersay.agi import Agi
from astersay.conf import settings


logger = getLogger(__name__)


class App:

    agi = None
    settings = None
    stream = None
    is_stopped = False

    def __init__(self, **agi_kwargs):
        log_info = logger.info
        log_info(_('Инициализация приложения начата.'))
        # Сначала запускаем создание базовых каталогов и настроек.
        settings.configure()
        log_info(_('Включены настройки для каталога по-умолчанию.'))

        # Запускается чтение входных параметров CGI.
        agi = Agi(**agi_kwargs)
        log_info(_('Создан экземпляр AGI: %s'), agi)
        params = agi.params
        dialog_name = params.get('agi_arg_1')
        settings.set_dialog_name(dialog_name)
        log_info(_('Установлено имя диалога: %s'), settings.dialog_name)
        if 'agi_arg_2' in params and params['agi_arg_2']:
            settings.work_dir = wd = params['agi_arg_2']
            log_info(_('Устанавливается рабочий каталог: %s'), wd)
            # Снова запускаем создание каталогов и настроек (уже конкретных).
            settings.configure()
            log_info(_('Включены настройки для каталога %s.'), wd)

        self.agi = agi
        self.settings = settings
        log_info(_('Инициализация приложения выполнена.'))

    def start(self):
        assert self.agi
        assert self.settings
        assert self.stream

        Dialog = self.settings.get_dialog_class()
        dialog = Dialog(self.agi, self.settings, self.stream)
        dialog.run()

    def stop(self):
        self.is_stopped = True

    def run(self, stream=None):
        try:
            if not stream:
                stream = open(3, 'rb')
            self.stream = stream
            self.start()
            self.stop()
        except Exception as e:
            self.stop()
            logger.error(str(e), exc_info=e)
            return 1
        return 0



#
# Copyright (c) 2020, Grigoriy Kramarenko
# All rights reserved.
# This file is distributed under the same license as the current project.
#
import json
from audioop import rms
from gettext import gettext as _
from logging import getLogger
from os.path import exists
from time import time

from astersay.exceptions import TokenError


class Listener:
    chunk_size = 4000
    # Максимальный размер потокового файла для Яндекса - 10 мегабайт.
    max_size = 10485760
    amplitude_size = 2
    sample_width = 2
    total_size = 0
    _continue = True
    logger = getLogger('astersay.backends.Listener')

    def __init__(self, stream, amplitude=None):
        """
        :param stream: файлоподобный обЪект потока голоса.
        :param amplitude: список (пустой) для записи результатов посекундного
                          анализа потока.
        :type amplitude: list
        """
        self._stream = stream
        if amplitude is None:
            amplitude = []
        self.amplitude = amplitude

    def has_continue(self):
        return self._continue and (
            self.total_size + self.chunk_size < self.max_size)

    def listen(self):
        chunk_size = self.chunk_size
        stream_read = self._stream.read
        logger_debug = self.logger.debug

        amplitude = self.amplitude
        amplitude_size = self.amplitude_size
        sample_width = self.sample_width
        chunk_number = 0
        sample = b''
        sample_second = int(time())
        while self.has_continue():
            chunk_number += 1
            chunk_second = int(time())
            chunk = stream_read(chunk_size)
            length = len(chunk)
            if sample_second < chunk_second:
                rms_value = rms(sample, sample_width)
                # logger_debug('rms=%d', rms_value)
                amplitude.append((sample_second, rms_value))
                if len(amplitude) > amplitude_size:
                    amplitude.pop(0)
                sample = b''
                sample_second = chunk_second
            sample += chunk
            # logger_debug('chunck %d length is %d', chunk_number, length)
            if length == 0:
                self.stop()
            self.total_size += length
            yield chunk
        logger_debug('listener ended, total size %d', self.total_size)

    def stop(self):
        self._continue = False
        self.logger.debug('listener stopped')


class BaseBackend:

    def __init__(self):
        cls = self.__class__
        name = '%s.%s' % (cls.__module__, cls.__name__)
        self.logger = getLogger(name)

    def __str__(self):
        return str(self.__class__)[8:-2]


class BaseToken:
    min_length = 32

    def __init__(self, key, expiration):
        self.key = str(key)
        self.expiration = float(expiration)

    def __str__(self):
        valid = 'Valid Token' if self.is_valid else 'Invalid Token'
        if self.is_expired:
            seconds = '(EXPIRED)'
        else:
            seconds = '(%d seconds)' % (self.expiration - time())
        return '%s "%s" %s' % (valid, self.display, seconds)

    @property
    def display(self):
        key = self.key
        if key:
            return '%s...%s' % (key[:8], key[-8:])
        return 'invalid'

    def expires_less_than(self, seconds=0):
        """
        Возвращает True если токен истекает менее чем через N секунд.
        """
        return self.expiration - seconds < time()

    @property
    def is_expired(self):
        return self.expires_less_than(0)

    @property
    def is_valid(self):
        return len(self.key) >= self.min_length


class BaseTokenManager:
    ALLOWED_ALGORITHMS = (
        'HS256',
        'HS384',
        'HS512',
        'RS256',
        'RS384',
        'RS512',
        'PS256',
    )
    token = None
    token_class = BaseToken
    token_filename = None

    def __init__(self, logger=None, **kwargs):
        if not logger:
            logger = getLogger(self.__class__.__module__)
        self.logger = logger

    def generate_token(self):
        """
        Переопределите этот метод в вашем классе. Он должен
        генерировать и возвращать экземпляр токена.
        """
        raise NotImplementedError

    def update_token(self):
        if not self.token:
            self.load_token()
        token = self.token
        if token and token.is_valid and not token.expires_less_than(360):
            self.logger.info(_('Время обновления токена ещё не подошло.'))
            return token
        self.logger.debug(_('Старый токен нужно обновить: %s'), token)
        try:
            self.token = self.generate_token()
        except ConnectionError as e:
            self.logger.critical(
                _('Ошибка во время обновления токена.'), exc_info=e)
        else:
            self.logger.info(_('Токен обновлен.'))
            self.save_token()
        return self.token

    def load_token(self):
        """Загружает токен из файла."""
        filename = self.token_filename
        assert filename
        if exists(filename):
            self.logger.debug(_('Файл токена существует.'))
            try:
                data = json.load(open(filename))
                self.token = self.token_class(data['key'], data['expiration'])
            except (ValueError, KeyError) as e:
                # Перезаписываем его.
                self.logger.error(_('Ошибка в файле токена: %s'), e)
                self.token = self.token_class('', 0)
                self.save_token()
        else:
            self.logger.debug(_('Файла токена не существует.'))

        self.logger.debug(_('Загрузка токена завершена: %s'), self.token)
        return self.token

    def save_token(self):
        token = self.token
        assert token
        filename = self.token_filename
        assert filename
        data = {'key': token.key, 'expiration': token.expiration}
        json.dump(data, open(filename, 'w'), indent=4)
        self.logger.info(_('Токен сохранён в файл: %s'), filename)
        return data

    def validate(self):
        token = self.token
        if not token:
            raise TokenError(_('Токен не установлен.'))
        if not token.is_expired:
            raise TokenError(_('Токен устарел.'))
        if not token.is_valid:
            raise TokenError(_('Токен недействителен.'))
        self.logger.debug(_('Токен находится в актуальном состоянии.'))

    def get_headers(self):
        assert self.token
        headers = {
            'Authorization': 'Bearer %s' % self.token.key,
        }
        return headers

    def get_metadata(self):
        assert self.token
        metadata = (
            ('authorization', 'Bearer %s' % self.token.key),
        )
        return metadata



#
#  Copyright (c) 2021. Egor Demushin.
#  All rights reserved.
#  This file is distributed under the same license as the current project.
#

import grpc
from copy import deepcopy
from gettext import gettext as _

from astersay.backends.tinkoff.base import TinkoffBaseBackend
from astersay.backends.tinkoff.proto import tts_pb2_grpc, tts_pb2
from astersay.utils import make_voice


class TinkoffSynthesizer(TinkoffBaseBackend):
    HOST = 'tts.tinkoff.ru:443'
    LANGUAGES = ('ru-RU',)
    VOICES = {
        'ru-RU': ('alyona', 'maxim'),
    }
    AUDIO_FORMATS = ('lpcm', 'oggopus')
    HERTZ_LIST = (8000, 16000, 32000, 48000)

    def __init__(self, settings, extra=None):
        TinkoffBaseBackend.__init__(self)
        self.set_token_manager(settings)

        conf = settings.tinkoff

        synthesizer = deepcopy(conf['synthesizer'])
        if extra:
            synthesizer.update(extra)

        self.storage_path = synthesizer['storage']
        self.convertor = synthesizer['convertor']

        language = synthesizer['lang']
        assert language in self.LANGUAGES
        self.language = language

        voice = synthesizer['voice']
        assert voice in self.VOICES[language]
        self.voice = voice

        speed = synthesizer['speed']
        assert 0.1 <= speed <= 3.0
        self.speed = speed

        audio_format = synthesizer['format']
        assert audio_format in self.AUDIO_FORMATS
        self.audio_format = audio_format

        sample_rate_hertz = synthesizer['sample_rate_hertz']
        assert sample_rate_hertz in self.HERTZ_LIST
        self.sample_rate_hertz = sample_rate_hertz

        self._credentials = grpc.ssl_channel_credentials()

    @property
    def message_params(self):
        return {
            'synthesizer': 'tinkoff',
            'lang': self.language,
            'voice': self.voice,
            'speed': self.speed,
            'sample_rate': self.sample_rate_hertz,
        }

    @property
    def _audio_config(self):
        return tts_pb2.AudioConfig(
            audio_encoding=tts_pb2.LINEAR16,
            sample_rate_hertz=self.sample_rate_hertz,
            speaking_rate=self.speed
        )

    @property
    def _voice_config(self):
        return tts_pb2.VoiceSelectionParams(
            name=self.voice,
            language_code=self.language
        )

    def build_request(self, text=''):
        return tts_pb2.SynthesizeSpeechRequest(
            input=tts_pb2.SynthesisInput(text=text),
            audio_config=self._audio_config,
            voice=self._voice_config
        )

    def make_message(self, text):
        """
        Создаёт полное сообщение для отправки на сервер и записи в
        спецификацию голосового файла.
        """
        assert len(text) <= 5000
        message = self.message_params
        message['text'] = text
        return message

    def synthesize(self, message):
        """
        Делает запрос сообщения на сервер и возвращает чистые audio-данные
        ответа или None.
        """
        assert isinstance(message, dict)
        self.token_manager.update_token()
        logger_debug = self.logger.debug

        headers = self.token_manager.get_headers()
        logger_debug(_('Заголовки синтеза речи: %s'), headers)
        logger_debug(_('Параметры синтеза речи: %s'), message)

        stub = tts_pb2_grpc.TextToSpeechStub(
            grpc.secure_channel(self.HOST, self._credentials))
        request = self.build_request(text=message['text'])
        metadata = self.token_manager.get_metadata()
        try:
            response = stub.Synthesize(request, metadata=metadata)
            return response.audio_content
        except Exception as e:
            self.logger.warning(_('Ошибка синтеза речи. %s'), e)

    def make_voice(self, text, early=False):
        """
        Ищет или создаёт голосовой файл для переданного текста,
        сохраняет его на диск и возвращает в виде пути без расширения,
        пригодного для передачи Астериску.
        """
        return make_voice(
            logger=self.logger,
            convertor=self.convertor,
            synthesize=self.synthesize,
            make_message=self.make_message,
            storage_path=self.storage_path,
            text=text,
            early=early
        )



#
#  Copyright (c) 2021. Egor Demushin.
#  All rights reserved.
#  This file is distributed under the same license as the current project.
#


class BaseAuth:
    def get_auth_param(self):
        """
        Метод должен вернуть два значение: ключ - куда добавляются параметры в запрос для модуля requests,
        например headers|params|auth|data (разные случаи бывают)
        И собственно отправляемые значение, может быть словарь/кортеж/список
        """
        raise NotImplementedError


class TokenHeaderAuth(BaseAuth):
    token = None
    auth_header = 'Bearer '

    def __init__(self, token, auth_header=None):
        self.token = token
        if auth_header:
            self.auth_header = auth_header

    def get_auth_param(self):
        assert self.token
        params = {
            'Authorization': f"{self.auth_header}{self.token}"
        }
        return 'headers', params


class TokenAuth(BaseAuth):
    ALLOWED_AUTH_KEYS = ('params', 'data')
    token = None
    token_key = 'token'
    auth_key = 'params'

    def __init__(self, token, token_key=None, auth_key=None):
        self.token = token
        if token_key:
            self.token_key = token_key
        if auth_key:
            assert auth_key in self.ALLOWED_AUTH_KEYS
            self.auth_key = auth_key

    def get_auth_param(self):
        assert self.token
        params = {
            self.token_key: self.token
        }
        return self.auth_key, params


class LoginPassAuth(BaseAuth):
    username_key = 'username'
    password_key = 'password'

    def __init__(self, username, password, username_key=None, password_key=None):
        self.username = username
        self.password = password

        if username_key:
            self.username_key = username_key
        if password_key:
            self.password_key = password_key

    def get_auth_param(self):
        params = {
            self.username_key: self.username,
            self.password_key: self.password
        }
        return 'params', params


class HttpBasicAuth(BaseAuth):
    def __init__(self, username, password):
        self.username = username
        self.password = password

    def get_auth_param(self):
        params = (self.username, self.password)
        return 'auth', params



#
# Copyright (c) 2020, Grigoriy Kramarenko
# All rights reserved.
# This file is distributed under the same license as the current project.
#
import json
import re
from gettext import gettext as _
from hashlib import sha256
from importlib import import_module
from os import system as os_system, remove as os_remove
from os.path import join as path_join, exists, basename
from types import GeneratorType
from unidecode import unidecode
from wave import open as wave_open


def import_string(dotted_path):
    """
    Import a dotted module path and return the attribute/class designated by the
    last name in the path. Raise ImportError if the import failed.
    """
    try:
        module_path, class_name = dotted_path.rsplit('.', 1)
    except ValueError as e:
        raise ImportError(
            "%s doesn't look like a module path." % dotted_path
        ) from e

    module = import_module(module_path)

    try:
        return getattr(module, class_name)
    except AttributeError as e:
        raise ImportError(
            'Module "%s" does not define a "%s" attribute/class' % (
                module_path, class_name)
        ) from e


def to_flat_list(data, skip=None, prebool=None, sort=False):
    """
    Преобразовывает многоуровневый объект в [отсортированный] плоский список.
    """
    result = []
    if skip is None:
        skip = ()
    if prebool is None:
        prebool = int

    def collect(item, prefix=''):
        if isinstance(item, dict):
            for key, value in item.items():
                if key in skip:
                    continue
                # Recursive collection for internal values.
                collect(value, prefix='%s%s:' % (prefix, key))
        elif isinstance(item, (list, tuple, range, GeneratorType)):
            for key, value in enumerate(item):
                # Recursive collection for internal values.
                collect(value, prefix='%s%d:' % (prefix, key))
        else:
            if isinstance(item, bool):
                value = prebool(item)
            else:
                value = item
            result.append('%s%s' % (prefix, str(value)))

    collect(data)
    if sort:
        result.sort()
    return result


def to_unique_string(data, skip=None, prebool=None, separator=';'):
    """
    Преобразовывает многоуровневый объект в уникальную строку.
    """
    if data is None:
        return ''
    elif isinstance(data, str):
        return data
    flat_list = to_flat_list(data, skip=skip, prebool=prebool, sort=True)
    return separator.join(flat_list)


def make_checksum(data, *args, **kwargs):
    uniq = to_unique_string(data, *args, **kwargs)
    return sha256(uniq.encode('utf-8')).hexdigest()


def prepare_dialog_name(s):
    """
    Преобразовывает имена разных алфавитов в латинницу и удаляет/заменяет
    лишние символы.
    """
    return unidecode(s).replace(' ', '_').replace('-', '_').replace("'", "")


def levenshtein_distance(text_1, text_2):
    """Алгоритм вычисления дистанции Левенштейна между двумя текстами."""

    length_1, length_2 = len(text_1), len(text_2)
    # Первым должен быть указан наименьший текст.
    if length_1 > length_2:
        text_1, text_2 = text_2, text_1
        length_1, length_2 = length_2, length_1

    current = range(length_1 + 1)
    for i in range(1, length_2 + 1):
        previous, current = current, [i] + [0] * length_1
        for j in range(1, length_1 + 1):
            add = previous[j] + 1
            delete = current[j - 1] + 1
            change = previous[j - 1]
            if text_1[j - 1] != text_2[i - 1]:
                change += 1
            current[j] = min(add, delete, change)
    return current[length_1]


def make_voice(logger, convertor, synthesize, storage_path, make_message, text,
               early=False, **kwargs):
    """
    Функция для создания головового файла(ов) для текста по переданным
    обработчикам синтезатора.
    """
    logger_debug = logger.debug
    logger_info = logger.info
    logger_info(_('Начинается синтез речи.'))

    # Убираем лишние пробелы.
    text = re.sub(r'\s+', ' ', text)

    def _find_voice(checksum):
        voice = path_join(storage_path, checksum)
        filename = '%s.wav' % voice
        # Именно такой файл уже есть, не нужно синтезировать.
        if exists(filename):
            logger_info(
                _('Речь %r существует и будет взята из хранилища.'), voice)
            found = True
        else:
            found = False
        return voice, filename, found

    def _save_info(voice, spec):
        spec_filename = '%s.json' % voice
        json.dump(spec, open(spec_filename, 'w'), indent=4, ensure_ascii=False)
        logger_debug(_('Сохранён файл спецификации: %s'), spec_filename)

    def _synthesize(voice, filename, message, spec):
        _save_info(voice, spec)

        audio_data = synthesize(message)

        src_filename = '%s.%s' % (voice, convertor['src_format'])
        with open(src_filename, 'wb') as f:
            f.write(audio_data)
        logger_info(_('Записан исходный файл речи: %s'), src_filename)
        command = convertor['command'] % (src_filename, filename)
        os_system(command)
        logger_info(_('Записан конечный файл речи: %s'), filename)

        if convertor.get('src_delete'):
            os_remove(src_filename)
        return True

    # Символ | является разделителем на несколько составных файлов, но
    # он может быть и цельным.
    message = make_message(text.replace('|', ''))
    spec = message.copy()
    spec['convertor'] = convertor
    checksum = make_checksum(spec)
    voice, filename, found = _find_voice(checksum)

    texts = [x for x in text.split('|') if x.strip()]
    if len(texts) == 1:
        if not found:
            logger_info(_('Синтезирую в речь текст: %r'), text)
            _synthesize(voice, filename, message, spec)
    elif not found:
        chunks = []
        for chunk_text in texts:
            chunk_message = make_message(chunk_text)
            chunk_spec = chunk_message.copy()
            chunk_spec['convertor'] = convertor
            chunk_checksum = make_checksum(chunk_spec)
            chunk_voice, chunk_filename, found = _find_voice(chunk_checksum)
            if not found:
                logger_info(_('Синтезирую в речь текст: %r'), chunk_text)
                _synthesize(chunk_voice, chunk_filename, chunk_message,
                            chunk_spec)
            chunks.append((chunk_voice, chunk_filename))

        # Если это заблаговременный синтез частей текста, то не собираем
        # конечный файл, а только все части.
        if early:
            logger_debug(_('Для предварительного синтеза речи конечный '
                           'файл не собирается.'))
            return voice

        frames = []
        params = None
        last_voice = chunks[-1][0]
        for chunk_voice, chunk_filename in chunks:
            with wave_open(chunk_filename) as f:
                if chunk_voice == last_voice:
                    params = f.getparams()
                frames.append(f.readframes(f.getnframes()))
        # Записываем информацию по слитому файлу.
        spec['chunks'] = [basename(v) for v, f in chunks]
        _save_info(voice, spec)
        # Записываем конечный, слитый файл.
        with wave_open(filename, 'wb') as f:
            f.setparams(params)
            for frame in frames:
                f.writeframes(frame)

    return voice



#
# Copyright (c) 2020, Grigoriy Kramarenko
# All rights reserved.
# This file is distributed under the same license as the current project.
#
from setuptools import setup

# Dynamically calculate the version based on astersay.VERSION.
version = __import__('astersay').get_version()

with open('README.rst', 'r') as f:
    long_description = f.read()

with open('requirements.txt') as f:
    requirements = [
        line.split('#', 1)[0].strip() for line in f.read().splitlines()
        if not line.strip().startswith('#')
    ]

with open('requirements-optional.txt') as f:
    dev_requirements = [
        line.split('#', 1)[0].strip() for line in f.read().splitlines()
        if not line.strip().startswith('#')
    ]

setup(
    name='astersay',
    version=version,
    description=(
        'This is a Python library for Asterisk to work with Yandex voice models.'
    ),
    long_description=long_description,
    author='Grigoriy Kramarenko',
    author_email='root@rosix.ru',
    url='https://gitlab.com/djbaldey/asterisk-dialogs/',
    license='BSD License',
    platforms='any',
    zip_safe=False,
    packages=['astersay'],
    scripts=[
        'scripts/astersay',
        'scripts/astersay-cgi',
        'scripts/astersay-dev',
        'scripts/astersay-t2v',
    ],
    include_package_data=True,
    install_requires=requirements,
    extras_require={
        'dev': dev_requirements,
    },
    classifiers=[
        # List of Classifiers: https://pypi.org/classifiers/
        'Development Status :: 5 - Production/Stable',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Intended Audience :: Telecommunications Industry',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: Russian',
        'Operating System :: POSIX',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Communications :: Internet Phone',
        'Topic :: Communications :: Telephony',
    ],
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tinkoff/cloud/tts/v1/tts.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from astersay.backends.google.proto.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tinkoff/cloud/tts/v1/tts.proto',
  package='tinkoff.cloud.tts.v1',
  syntax='proto3',
  serialized_options=b'ZQgithub.com/TinkoffCreditSystems/voicekit-examples/golang/pkg/tinkoff/cloud/tts/v1\242\002\005TVKSS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1etinkoff/cloud/tts/v1/tts.proto\x12\x14tinkoff.cloud.tts.v1\x1a\x1cgoogle/api/annotations.proto\"c\n\x05Voice\x12\x16\n\x0elanguage_codes\x18\x01 \x03(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12!\n\x19natural_sample_rate_hertz\x18\x04 \x01(\x05J\x04\x08\x03\x10\x04R\x0bssml_gender\"*\n\x11ListVoicesRequest\x12\x15\n\rlanguage_code\x18\x01 \x01(\t\"B\n\x13ListVoicesResponses\x12+\n\x06voices\x18\x01 \x03(\x0b\x32\x1b.tinkoff.cloud.tts.v1.Voice\",\n\x0eSynthesisInput\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x0c\n\x04ssml\x18\x02 \x01(\t\"N\n\x14VoiceSelectionParams\x12\x15\n\rlanguage_code\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\tJ\x04\x08\x03\x10\x04R\x0bssml_gender\"\x9f\x01\n\x0b\x41udioConfig\x12;\n\x0e\x61udio_encoding\x18\x01 \x01(\x0e\x32#.tinkoff.cloud.tts.v1.AudioEncoding\x12\x15\n\rspeaking_rate\x18\x02 \x01(\x01\x12\x19\n\x11sample_rate_hertz\x18\x05 \x01(\x05J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05R\x05pitchR\x0evolume_gain_db\"\xc2\x01\n\x17SynthesizeSpeechRequest\x12\x33\n\x05input\x18\x01 \x01(\x0b\x32$.tinkoff.cloud.tts.v1.SynthesisInput\x12\x39\n\x05voice\x18\x02 \x01(\x0b\x32*.tinkoff.cloud.tts.v1.VoiceSelectionParams\x12\x37\n\x0c\x61udio_config\x18\x03 \x01(\x0b\x32!.tinkoff.cloud.tts.v1.AudioConfig\"1\n\x18SynthesizeSpeechResponse\x12\x15\n\raudio_content\x18\x01 \x01(\x0c\"8\n!StreamingSynthesizeSpeechResponse\x12\x13\n\x0b\x61udio_chunk\x18\x01 \x01(\x0c*\xe2\x01\n\rAudioEncoding\x12\x18\n\x14\x45NCODING_UNSPECIFIED\x10\x00\x12\x0c\n\x08LINEAR16\x10\x01\x12\t\n\x05MULAW\x10\x03\x12\x08\n\x04\x41LAW\x10\x08\x12\x0c\n\x08RAW_OPUS\x10\x0b\"\x04\x08\x02\x10\x02\"\x04\x08\x04\x10\x04\"\x04\x08\x05\x10\x05\"\x04\x08\x06\x10\x06\"\x04\x08\x07\x10\x07\"\x04\x08\t\x10\t\"\x04\x08\n\x10\n\"\x04\x08\x0c\x10\x0c*\x04\x46LAC*\x03\x41MR*\x06\x41MR_WB*\x08OGG_OPUS*\x16SPEEX_WITH_HEADER_BYTE*\tLINEAR32F*\nOGG_VORBIS*\nMPEG_AUDIO2\x9b\x03\n\x0cTextToSpeech\x12}\n\nListVoices\x12\'.tinkoff.cloud.tts.v1.ListVoicesRequest\x1a).tinkoff.cloud.tts.v1.ListVoicesResponses\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v1/tts:list_voices\x12\x8a\x01\n\nSynthesize\x12-.tinkoff.cloud.tts.v1.SynthesizeSpeechRequest\x1a..tinkoff.cloud.tts.v1.SynthesizeSpeechResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/tts:synthesize:\x01*\x12\x7f\n\x13StreamingSynthesize\x12-.tinkoff.cloud.tts.v1.SynthesizeSpeechRequest\x1a\x37.tinkoff.cloud.tts.v1.StreamingSynthesizeSpeechResponse0\x01\x42[ZQgithub.com/TinkoffCreditSystems/voicekit-examples/golang/pkg/tinkoff/cloud/tts/v1\xa2\x02\x05TVKSSb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])

_AUDIOENCODING = _descriptor.EnumDescriptor(
  name='AudioEncoding',
  full_name='tinkoff.cloud.tts.v1.AudioEncoding',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ENCODING_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LINEAR16', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MULAW', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALAW', index=3, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RAW_OPUS', index=4, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=894,
  serialized_end=1120,
)
_sym_db.RegisterEnumDescriptor(_AUDIOENCODING)

AudioEncoding = enum_type_wrapper.EnumTypeWrapper(_AUDIOENCODING)
ENCODING_UNSPECIFIED = 0
LINEAR16 = 1
MULAW = 3
ALAW = 8
RAW_OPUS = 11



_VOICE = _descriptor.Descriptor(
  name='Voice',
  full_name='tinkoff.cloud.tts.v1.Voice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language_codes', full_name='tinkoff.cloud.tts.v1.Voice.language_codes', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='tinkoff.cloud.tts.v1.Voice.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='natural_sample_rate_hertz', full_name='tinkoff.cloud.tts.v1.Voice.natural_sample_rate_hertz', index=2,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=185,
)


_LISTVOICESREQUEST = _descriptor.Descriptor(
  name='ListVoicesRequest',
  full_name='tinkoff.cloud.tts.v1.ListVoicesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language_code', full_name='tinkoff.cloud.tts.v1.ListVoicesRequest.language_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=187,
  serialized_end=229,
)


_LISTVOICESRESPONSES = _descriptor.Descriptor(
  name='ListVoicesResponses',
  full_name='tinkoff.cloud.tts.v1.ListVoicesResponses',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='voices', full_name='tinkoff.cloud.tts.v1.ListVoicesResponses.voices', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=231,
  serialized_end=297,
)


_SYNTHESISINPUT = _descriptor.Descriptor(
  name='SynthesisInput',
  full_name='tinkoff.cloud.tts.v1.SynthesisInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='tinkoff.cloud.tts.v1.SynthesisInput.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ssml', full_name='tinkoff.cloud.tts.v1.SynthesisInput.ssml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=343,
)


_VOICESELECTIONPARAMS = _descriptor.Descriptor(
  name='VoiceSelectionParams',
  full_name='tinkoff.cloud.tts.v1.VoiceSelectionParams',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='language_code', full_name='tinkoff.cloud.tts.v1.VoiceSelectionParams.language_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='tinkoff.cloud.tts.v1.VoiceSelectionParams.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=345,
  serialized_end=423,
)


_AUDIOCONFIG = _descriptor.Descriptor(
  name='AudioConfig',
  full_name='tinkoff.cloud.tts.v1.AudioConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio_encoding', full_name='tinkoff.cloud.tts.v1.AudioConfig.audio_encoding', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speaking_rate', full_name='tinkoff.cloud.tts.v1.AudioConfig.speaking_rate', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sample_rate_hertz', full_name='tinkoff.cloud.tts.v1.AudioConfig.sample_rate_hertz', index=2,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=426,
  serialized_end=585,
)


_SYNTHESIZESPEECHREQUEST = _descriptor.Descriptor(
  name='SynthesizeSpeechRequest',
  full_name='tinkoff.cloud.tts.v1.SynthesizeSpeechRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='input', full_name='tinkoff.cloud.tts.v1.SynthesizeSpeechRequest.input', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voice', full_name='tinkoff.cloud.tts.v1.SynthesizeSpeechRequest.voice', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audio_config', full_name='tinkoff.cloud.tts.v1.SynthesizeSpeechRequest.audio_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=588,
  serialized_end=782,
)


_SYNTHESIZESPEECHRESPONSE = _descriptor.Descriptor(
  name='SynthesizeSpeechResponse',
  full_name='tinkoff.cloud.tts.v1.SynthesizeSpeechResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio_content', full_name='tinkoff.cloud.tts.v1.SynthesizeSpeechResponse.audio_content', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=784,
  serialized_end=833,
)


_STREAMINGSYNTHESIZESPEECHRESPONSE = _descriptor.Descriptor(
  name='StreamingSynthesizeSpeechResponse',
  full_name='tinkoff.cloud.tts.v1.StreamingSynthesizeSpeechResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='audio_chunk', full_name='tinkoff.cloud.tts.v1.StreamingSynthesizeSpeechResponse.audio_chunk', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=835,
  serialized_end=891,
)

_LISTVOICESRESPONSES.fields_by_name['voices'].message_type = _VOICE
_AUDIOCONFIG.fields_by_name['audio_encoding'].enum_type = _AUDIOENCODING
_SYNTHESIZESPEECHREQUEST.fields_by_name['input'].message_type = _SYNTHESISINPUT
_SYNTHESIZESPEECHREQUEST.fields_by_name['voice'].message_type = _VOICESELECTIONPARAMS
_SYNTHESIZESPEECHREQUEST.fields_by_name['audio_config'].message_type = _AUDIOCONFIG
DESCRIPTOR.message_types_by_name['Voice'] = _VOICE
DESCRIPTOR.message_types_by_name['ListVoicesRequest'] = _LISTVOICESREQUEST
DESCRIPTOR.message_types_by_name['ListVoicesResponses'] = _LISTVOICESRESPONSES
DESCRIPTOR.message_types_by_name['SynthesisInput'] = _SYNTHESISINPUT
DESCRIPTOR.message_types_by_name['VoiceSelectionParams'] = _VOICESELECTIONPARAMS
DESCRIPTOR.message_types_by_name['AudioConfig'] = _AUDIOCONFIG
DESCRIPTOR.message_types_by_name['SynthesizeSpeechRequest'] = _SYNTHESIZESPEECHREQUEST
DESCRIPTOR.message_types_by_name['SynthesizeSpeechResponse'] = _SYNTHESIZESPEECHRESPONSE
DESCRIPTOR.message_types_by_name['StreamingSynthesizeSpeechResponse'] = _STREAMINGSYNTHESIZESPEECHRESPONSE
DESCRIPTOR.enum_types_by_name['AudioEncoding'] = _AUDIOENCODING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Voice = _reflection.GeneratedProtocolMessageType('Voice', (_message.Message,), {
  'DESCRIPTOR' : _VOICE,
  '__module__' : 'tinkoff.cloud.tts.v1.tts_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.tts.v1.Voice)
  })
_sym_db.RegisterMessage(Voice)

ListVoicesRequest = _reflection.GeneratedProtocolMessageType('ListVoicesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTVOICESREQUEST,
  '__module__' : 'tinkoff.cloud.tts.v1.tts_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.tts.v1.ListVoicesRequest)
  })
_sym_db.RegisterMessage(ListVoicesRequest)

ListVoicesResponses = _reflection.GeneratedProtocolMessageType('ListVoicesResponses', (_message.Message,), {
  'DESCRIPTOR' : _LISTVOICESRESPONSES,
  '__module__' : 'tinkoff.cloud.tts.v1.tts_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.tts.v1.ListVoicesResponses)
  })
_sym_db.RegisterMessage(ListVoicesResponses)

SynthesisInput = _reflection.GeneratedProtocolMessageType('SynthesisInput', (_message.Message,), {
  'DESCRIPTOR' : _SYNTHESISINPUT,
  '__module__' : 'tinkoff.cloud.tts.v1.tts_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.tts.v1.SynthesisInput)
  })
_sym_db.RegisterMessage(SynthesisInput)

VoiceSelectionParams = _reflection.GeneratedProtocolMessageType('VoiceSelectionParams', (_message.Message,), {
  'DESCRIPTOR' : _VOICESELECTIONPARAMS,
  '__module__' : 'tinkoff.cloud.tts.v1.tts_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.tts.v1.VoiceSelectionParams)
  })
_sym_db.RegisterMessage(VoiceSelectionParams)

AudioConfig = _reflection.GeneratedProtocolMessageType('AudioConfig', (_message.Message,), {
  'DESCRIPTOR' : _AUDIOCONFIG,
  '__module__' : 'tinkoff.cloud.tts.v1.tts_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.tts.v1.AudioConfig)
  })
_sym_db.RegisterMessage(AudioConfig)

SynthesizeSpeechRequest = _reflection.GeneratedProtocolMessageType('SynthesizeSpeechRequest', (_message.Message,), {
  'DESCRIPTOR' : _SYNTHESIZESPEECHREQUEST,
  '__module__' : 'tinkoff.cloud.tts.v1.tts_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.tts.v1.SynthesizeSpeechRequest)
  })
_sym_db.RegisterMessage(SynthesizeSpeechRequest)

SynthesizeSpeechResponse = _reflection.GeneratedProtocolMessageType('SynthesizeSpeechResponse', (_message.Message,), {
  'DESCRIPTOR' : _SYNTHESIZESPEECHRESPONSE,
  '__module__' : 'tinkoff.cloud.tts.v1.tts_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.tts.v1.SynthesizeSpeechResponse)
  })
_sym_db.RegisterMessage(SynthesizeSpeechResponse)

StreamingSynthesizeSpeechResponse = _reflection.GeneratedProtocolMessageType('StreamingSynthesizeSpeechResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMINGSYNTHESIZESPEECHRESPONSE,
  '__module__' : 'tinkoff.cloud.tts.v1.tts_pb2'
  # @@protoc_insertion_point(class_scope:tinkoff.cloud.tts.v1.StreamingSynthesizeSpeechResponse)
  })
_sym_db.RegisterMessage(StreamingSynthesizeSpeechResponse)


DESCRIPTOR._options = None

_TEXTTOSPEECH = _descriptor.ServiceDescriptor(
  name='TextToSpeech',
  full_name='tinkoff.cloud.tts.v1.TextToSpeech',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1123,
  serialized_end=1534,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListVoices',
    full_name='tinkoff.cloud.tts.v1.TextToSpeech.ListVoices',
    index=0,
    containing_service=None,
    input_type=_LISTVOICESREQUEST,
    output_type=_LISTVOICESRESPONSES,
    serialized_options=b'\202\323\344\223\002\025\022\023/v1/tts:list_voices',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Synthesize',
    full_name='tinkoff.cloud.tts.v1.TextToSpeech.Synthesize',
    index=1,
    containing_service=None,
    input_type=_SYNTHESIZESPEECHREQUEST,
    output_type=_SYNTHESIZESPEECHRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\"\022/v1/tts:synthesize:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StreamingSynthesize',
    full_name='tinkoff.cloud.tts.v1.TextToSpeech.StreamingSynthesize',
    index=2,
    containing_service=None,
    input_type=_SYNTHESIZESPEECHREQUEST,
    output_type=_STREAMINGSYNTHESIZESPEECHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TEXTTOSPEECH)

DESCRIPTOR.services_by_name['TextToSpeech'] = _TEXTTOSPEECH

# @@protoc_insertion_point(module_scope)



#
#  Copyright (c) 2021. Egor Demushin.
#  All rights reserved.
#  This file is distributed under the same license as the current project.
#

import json


class BaseParser:
    parser_params = {}

    def __init__(self, conf=None):
        if conf:
            self.parser_params.update(conf)

    def parse(self, text):
        """
        Переопределите этот метод в вашем классе.
        """
        raise NotImplementedError


class PlainTextParser(BaseParser):
    parser_params = {
        'variable_name': 'http_answer'
    }

    def parse(self, text):
        key = self.parser_params['variable_name']
        return {key: text}


class JsonParser(BaseParser):
    def parse(self, text):
        return json.loads(text, **self.parser_params)



#
# Copyright (c) 2020, Grigoriy Kramarenko
# All rights reserved.
# This file is distributed under the same license as the current project.
#
from copy import deepcopy
from gettext import gettext as _
from json import loads, dumps
from threading import Timer
from websocket import create_connection

from astersay.backends.base import BaseBackend, Listener


class VoskRecognizer(BaseBackend):
    pause = True

    HERTZ_LIST = (48000, 16000, 8000)
    # Счётчик текущих предварительных результатов. Сбрасывается финальным.
    partials_counter = 0

    def __init__(self, settings, extra=None):
        BaseBackend.__init__(self)

        conf = settings.vosk
        recognizer = deepcopy(conf['recognizer'])
        if extra:
            recognizer.update(extra)

        sample_rate_hertz = recognizer['sample_rate_hertz']
        assert sample_rate_hertz in self.HERTZ_LIST
        self.sample_rate_hertz = sample_rate_hertz

        chunk_size = recognizer['chunk_size']
        assert chunk_size >= 1024 and chunk_size % 2 == 0
        self.chunk_size = chunk_size

        max_size = recognizer['max_size']
        assert max_size >= 1048576 and max_size % 2 == 0
        self.max_size = max_size

        max_time = recognizer['max_time']
        assert max_time >= 1
        self.max_time = max_time

        self.host = conf['connection']['host']
        self.port = conf['connection']['port']

    def create_connection(self, config=None):
        self.ws = None
        try:
            # Создаём сединение с сервером Vosk.
            ws = create_connection("ws://%s:%d" % (self.host, self.port))
        except Exception as e:
            self.logger.critical(str(e), exc_info=e)
            return
        if not ws.connected:
            self.logger.critical(_('Соединение с вэбсокетом было закрыто.'))
            return
        # TODO: сделать проверку соединения.
        # Отправляем конфигурацию, она запомнится для сокет-соединения.
        if config:
            # config = {
            #     'word_list': 'да нет наверное ага хорошо лады окей',
            #     'sample_rate': 8000,
            # }
            ws.send(dumps({'config': config}))
        self.ws = ws
        return ws

    def _recognize(self, listener):
        """Возвращает итератор ответов Vosk."""
        ws = self.ws
        send = ws.send_binary
        recv = ws.recv
        try:
            for chunk in listener.listen():
                if self.pause:
                    chunk = b''
                send(chunk)
                yield loads(recv())
        except Exception as e:
            self.logger.critical(str(e), exc_info=e)

    def listen(self, dialog):
        """
        Распознавание текста для диалога производится вплоть до его завершения
        или превышения объёма стрима. Возвращает итератор текста.
        """
        logger_debug = self.logger.debug
        logger_info = self.logger.info
        logger_info(_('Начинается распознавание речи для диалога.'))

        ws = self.create_connection()
        if not ws:
            # Мы вынуждены завершать диалог, если распознавание не работает.
            dialog.stop()
            return

        listener = Listener(dialog.stream, dialog.amplitude)
        self.listener = listener
        # Максимальный размер потокового файла для Vosk задаётся настройками.
        listener.max_size = self.max_size
        listener.chunk_size = self.chunk_size

        text_to_text_buffer = dialog.text_to_text_buffer
        get_text_buffer = dialog.get_last_text_buffer

        # Максимальное время потока для Vosk - 5 минут.
        timer = Timer(self.max_time, listener.stop)
        timer.start()
        self.partials_counter = 0
        text_buffer = None
        for answer in self._recognize(listener):
            # Каждый раз получаем самый последний буфер, т.к. он может быть
            # создан в процессе работы. Но для сохранения финальных результатов
            # используем запомненный.
            if text_buffer is None:
                text_buffer = get_text_buffer()
                logger_info(_('Работаем с буфером %s'), text_buffer.key)
            logger_debug(_('Ответ Vosk: %s'), answer)
            if 'result' in answer:
                text = answer['text']
                logger_info(
                    _('Финальный текст в буфер %(buffer)s: %(text)s'),
                    {'text': text, 'buffer': text_buffer.key}
                )
                text_to_text_buffer(text, fixed=True, text_buffer=text_buffer)
                self.partials_counter = 0
                # После каждого финального текста сбрасываем привязку к буферу.
                text_buffer = None
            elif 'partial' in answer:
                text = answer['partial']
                logger_debug(
                    _('Предварительный текст в буфер %(buffer)s: %(text)s'),
                    {'text': text, 'buffer': text_buffer.key}
                )
                text_to_text_buffer(text, fixed=False, text_buffer=text_buffer)
                self.partials_counter += 1
            if dialog.is_closed:
                listener.stop()
                logger_debug(_('Диалог прекратился и слушатель тоже.'))
                break
        logger_debug(_('Цикл завершён.'))
        timer.cancel()
        dialog.stream_size += listener.total_size
